format_token_stream

Function format_token_stream 

pub fn format_token_stream(tokens: TokenStream) -> String
Format a token stream into a pretty-printed Rust source string.

Panics

Panics if the generated token stream is not valid Rust syntax, which indicates a bug in the code generator.