Code generation for relation support: Include, WithRelations, batched loading.
Structs
- Relation
Info - Information about a relation from one model to another.
Functions
- collect_
relations - Collect relation fields for a model, resolving against the full schema.
- gen_
find_ many_ include - Generate
include()andexec_with_relations()methods for FindMany. - gen_
relation_ types - Generate the Include struct, WithRelations struct, and include-aware query methods.