pub fn collect_relations<'a>(
model: &'a Model,
schema: &'a Schema,
) -> Vec<RelationInfo<'a>>Expand description
Collect relation fields for a model, resolving against the full schema.
pub fn collect_relations<'a>(
model: &'a Model,
schema: &'a Schema,
) -> Vec<RelationInfo<'a>>Collect relation fields for a model, resolving against the full schema.